import Component from '@ember/component';
import NativeArray from '@ember/array/-private/native-array';
import FormValidatorChild from './form-validator/child';
import { ChangesetDef } from 'ember-changeset/types';
export interface Changeset extends ChangesetDef {
    validate: (key?: any) => any;
}
export default class FormValidator extends Component {
    layout: any;
    didInvokeValidate: boolean;
    childValidators: NativeArray<{}>;
    changeset: Changeset | null;
    showAllValidationFields: boolean;
    /**
     * Registers a `FormValidatorChild` via adding to the `childValidators` array
     *
     * @param child The form validator child to register
     */
    registerChild(child: FormValidatorChild): void;
    /**
     * Deregisters a `FormValidatorChild` via removing it from the `childValidators` array
     *
     * @param child The form validator child to deregister
     */
    deregisterChild(child: FormValidatorChild): void;
    /**
     * Validate the changeset. Resolve promise if successful, reject if not
     *
     * @param changeset The changeset to validate
     */
    validateChangeset(changeset: Changeset): any;
    /**
     * Submit the form. Check parent changeset and all child changesets to see if they validate
     * If they do validate, try to invoke `submit`. Otherwise show all validation field errors
     */
    submitForm(): Promise<undefined>;
}
