import Component from '@ember/component';
export default class InputValidator extends Component {
    layout: any;
    classNames: string[];
    classNameBindings: string[];
    labelClass: string;
    errorClass: string;
    label: boolean;
    hideErrorText: boolean;
    hasFocusedOut: boolean;
    error: null;
    parentView: any;
    target: any;
    /**
     * Checks to see if we should show the error
     * If there is an error and you have focused out of the field or your supposed to show all errors then this value is true
     *
     * @param hasError If there is an error for this field
     * @param hasFocusedOut If the user has focused out of the field
     * @param showAllValidationFields If we should be showing all validation fields
     */
    readonly showError: boolean | undefined;
    /**
     * Checks to see if there is an error related to the field
     *
     * @param error.length Error array length
     */
    hasError: boolean | undefined;
    /**
     * The label for the field
     *
     * @param text `text` that is passed in from the user
     */
    fieldLabel: string | undefined;
    /**
     * Checks to see if we should be showing all validation fields. This is changed via the `FormValidator.showAllValidationFields` property
     *
     * @param targetView.showAllValidationFields `text` that is passed in from the user
     */
    showAllValidationFields: boolean | undefined;
    /**
     * Afer the changeset has changed, this observer resets `hasFocusedOut`
     */
    changesetHasChanged(): void;
    /**
     * Goes up through the parent components to find an instance of a `FormValidator` or `FormValidatorChild`
     *
     * @param targetView.showAllValidationFields `text` that is passed in from the user
     */
    readonly targetView: any;
    private getFormComponent;
    /**
     * When user focuses out of the field, this sets `hasFocusedOut` to `true`
     */
    focusOut(): this["hasFocusedOut"];
    /**
     * Defines a new property called error, which reads the errors from the changeset for the specific value.
     * For example, if you pass in a target of `name` error is set to `targetView.changeset.error.name.validation` which gives us the errors that we display to the user
     */
    defineErrorProperty(): void;
    didInsertElement(): void;
}
